==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvacation0.14-1.2rc2.tar.gz: vacation/vac_init.php <==
<?php

chdir("..");
session_start();


if (!isset($config_php))
	include("../config/config.php");
if (!isset($strings_php))
	include("../functions/strings.php");
if (!isset($page_header_php))
	include("../functions/page_header.php");
if (!isset($imap_php))
	include("../functions/imap.php");
if (!isset($array_php))
	include("../functions/array.php");
if (!isset($i18n_php))
	include("../functions/i18n.php");
if (!isset($plugin_php))
	include("../functions/plugin.php");
if (!isset($display_messages_php))
	include("../functions/display_messages.php");

include("../functions/auth.php");

is_logged_in();

include("../src/load_prefs.php");
$chosen_language = getPref($data_dir, $username, "language");

include("../plugins/vacation/config.php");

function sqStripSlashes($string) {
      if (get_magic_quotes_gpc()) {
         $string = stripslashes($string);
      }
      return $string;
   }  


displayPageHeader($color, "None");

echo "<br>\n";
echo "<table width=95% align=center border=0 cellpadding=2 cellspacing=0><tr><td
 bgcolor=\"$color[0]\">\n";?>
<center><b><?php echo _("Options") ." - ".$vac_header_line."</b></center></td></tr></table>\n";

echo "<form method=post action=\"vac_init.php\">\n";

if ($edit_vacation) {
   include("../plugins/vacation/vacation.php");
}

echo "</form>\n";


//
// do_ftp
// perform various ftp actions

function do_ftp($action, $remotefile, $localfile) {

   global $username, $key, $onetimepad, $ftp_server;
   global $mail_vacation_ftpfile_binary;

   $password = OneTimePadDecrypt($key, $onetimepad); // decrypt password

   $result=FALSE;

//   $fs=ftp_connect($ftp_server);
//   if(!$fs) {
//      echo "Could not connect to FTP server.<br>\n";
//   }
//   $ftpconn=ftp_login($fs, $username, $password);
//   if(!$ftpconn) {
//      echo "Failed to login to FTP server.<br>\n";
//   }
//   if ($use_passive) {
//      if (!ftp_pasv($fs, TRUE)) {
//         echo "Unable to switch to passive FTP mode.<br>\n";
//      }
//   }

   switch($action) {
      case "list": // check whether file exists
	$ftpflist = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." list ".$remotefile." ???");
//         $ftpflist=ftp_nlist($fs, $remotefile);
         if ($ftpflist == $remotefile) {
            $result=TRUE;
         } else {
            $result=FALSE;
         }
         break;
      case "put": // upload $remotefile to $localfile
	$ftpfput=exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." put ".$localfile." ".$remotefile);
         if($ftpfput <> "") {
            $result=TRUE;
         } else {
            echo "An error occured uploading the file.";
            $result=FALSE;
         }
         break;
      case "get": // download $remotefile to $localfile
	$ftpfget=exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." get ".$remotefile." ".$localfile);
//         $ftpfget=ftp_get($fs, $localfile, $remotefile, FTP_ASCII);
         if($ftpfget <> "") {
            $result=TRUE;
         } else {
            echo "An error occured downloading the file.";
            $result=FALSE;
         }
         break;
      case "delete": //delete files listed in $remotefile if they exist
         $remotefiles=explode(",",$remotefile);
         $result=TRUE;
         for ($i=0; $i < count($remotefiles); $i++) {

//            $ftpflist=ftp_nlist($fs, $remotefiles[$i]); // Check file exists
	$ftpflist = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." list ".$remotefiles[$i]." ???");
            if ($ftpflist == $remotefiles[$i]) {
	$ftpfdel = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." delete ".$remotefiles[$i]." ???");
//               $ftpfdel=ftp_delete($fs, $remotefiles[$i]);
               if(!$ftpfdel) {
                  echo "An error occured deleting the file.";
                  $result=FALSE;
               }
            }
         }
         break;
      default:
         echo "Unknown action $action in do_ftp.<br>\n";
         $result=FALSE;
   }

//   $ftpquit=ftp_quit($fs); //close active connection
   return $result;
}

//
// download_data
// download remote file and return its contents

function download_data($remotefile) {
   global $attachment_dir, $username;

   $tempfile=$attachment_dir."/".$username.".mailcfg.tmp";
   
   $result="";
   
   $ftp_get=do_ftp("get", $remotefile, $tempfile);
   
   if($ftp_get) {
      $tempfilehandle=fopen($tempfile, "r");
      while (!feof($tempfilehandle)) {
         $result .= fgets($tempfilehandle, 80);
      }
      fclose($tempfilehandle);
      unlink($tempfile);
   }
   
   return $result;
}
//
// download_data
// save string into a file and upload it

function upload_data($string, $remotefile) {
   global $attachment_dir, $username;
   
   $tempfile=$attachment_dir."/".$username.".mailcfg.tmp";
   
   $tempfilehandle=fopen($tempfile, "w");
   fwrite($tempfilehandle, sqStripSlashes($string));
   fclose($tempfilehandle);
  
   $ftp_put=do_ftp("put", $remotefile, $tempfile);
   unlink($tempfile);  // delete localfile
   
   return $ftp_put;
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvacation0.15-1.43a.tar.gz: vacation/vac_init.php <==
<?php

// chdir("..");
// session_start();



define('SM_PATH','../../');

/* SquirrelMail required files. */
require_once(SM_PATH . 'include/validate.php');
require_once(SM_PATH . 'functions/page_header.php');
require_once(SM_PATH . 'functions/display_messages.php');
require_once(SM_PATH . 'functions/imap.php');
require_once(SM_PATH . 'include/load_prefs.php');

$chosen_language = getPref($data_dir, $username, "language");

include_once(SM_PATH . "plugins/vacation/config.php");

function mysqStripSlashes($string) {
      if (get_magic_quotes_gpc()) {
         $string = stripslashes($string);
      }
      return $string;
   }  


displayPageHeader($color, "None");

echo "<br>\n";
echo "<table width=95% align=center border=0 cellpadding=2 cellspacing=0><tr><td
 bgcolor=\"$color[0]\">\n";?>
<center><b><?php echo _("Options") ." - ".$vac_header_line."</b></center></td></tr></table>\n";

echo "<form method=post action=\"vac_init.php\">\n";

if ($edit_vacation) {
   include_once(SM_PATH . "plugins/vacation/vacation.php");
}

echo "</form>\n";


//
// do_ftp
// perform various ftp actions

function do_ftp($action, $remotefile, $localfile) {

   global $username, $key, $onetimepad, $ftp_server;
   global $mail_vacation_ftpfile_binary;

   $password = OneTimePadDecrypt($key, $onetimepad); // decrypt password

   $result=FALSE;

//   $fs=ftp_connect($ftp_server);
//   if(!$fs) {
//      echo "Could not connect to FTP server.<br>\n";
//   }
//   $ftpconn=ftp_login($fs, $username, $password);
//   if(!$ftpconn) {
//      echo "Failed to login to FTP server.<br>\n";
//   }
//   if ($use_passive) {
//      if (!ftp_pasv($fs, TRUE)) {
//         echo "Unable to switch to passive FTP mode.<br>\n";
//      }
//   }

   switch($action) {
      case "list": // check whether file exists
	$ftpflist = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." list ".$remotefile." ???");
//         $ftpflist=ftp_nlist($fs, $remotefile);
         if ($ftpflist == $remotefile) {
            $result=TRUE;
         } else {
            $result=FALSE;
         }
         break;
      case "put": // upload $remotefile to $localfile
	$ftpfput=exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." put ".$localfile." ".$remotefile);
         if($ftpfput <> "") {
            $result=TRUE;
         } else {
            echo "An error occured uploading the file.";
            $result=FALSE;
         }
         break;
      case "get": // download $remotefile to $localfile
	$ftpfget=exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." get ".$remotefile." ".$localfile);
//         $ftpfget=ftp_get($fs, $localfile, $remotefile, FTP_ASCII);
         if($ftpfget <> "") {
            $result=TRUE;
         } else {
            echo "An error occured downloading the file.";
            $result=FALSE;
         }
         break;
      case "delete": //delete files listed in $remotefile if they exist
         $remotefiles=explode(",",$remotefile);
         $result=TRUE;
         for ($i=0; $i < count($remotefiles); $i++) {

//            $ftpflist=ftp_nlist($fs, $remotefiles[$i]); // Check file exists
	$ftpflist = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." list ".$remotefiles[$i]." ???");
            if ($ftpflist == $remotefiles[$i]) {
	$ftpfdel = exec($mail_vacation_ftpfile_binary." ".$ftp_server." ".$username." ".$password." delete ".$remotefiles[$i]." ???");
//               $ftpfdel=ftp_delete($fs, $remotefiles[$i]);
               if(!$ftpfdel) {
                  echo "An error occured deleting the file.";
                  $result=FALSE;
               }
            }
         }
         break;
      default:
         echo "Unknown action $action in do_ftp.<br>\n";
         $result=FALSE;
   }

//   $ftpquit=ftp_quit($fs); //close active connection
   return $result;
}

//
// download_data
// download remote file and return its contents

function download_data($remotefile) {
   global $attachment_dir, $username;

   $tempfile=$attachment_dir."/".$username.".mailcfg.tmp";
   
   $result="";
   
   $ftp_get=do_ftp("get", $remotefile, $tempfile);
   
   if($ftp_get) {
      $tempfilehandle=fopen($tempfile, "r");
      while (!feof($tempfilehandle)) {
         $result .= fgets($tempfilehandle, 80);
      }
      fclose($tempfilehandle);
      unlink($tempfile);
   }
   
   return $result;
}
//
// download_data
// save string into a file and upload it

function upload_data($string, $remotefile) {
   global $attachment_dir, $username;
   
   $tempfile=$attachment_dir."/".$username.".mailcfg.tmp";
   
   $tempfilehandle=fopen($tempfile, "w");
   fwrite($tempfilehandle, mysqStripSlashes($string));
   fclose($tempfilehandle);
  
   $ftp_put=do_ftp("put", $remotefile, $tempfile);
   unlink($tempfile);  // delete localfile
   
   return $ftp_put;
}

?>
